#!/bin/sh
# Check if CC client is working
# Michael Tosch
#

PATH=/bin:/usr/bin:/usr/proc/bin:/opt/rational/clearcase/bin:/usr/atria/bin:/usr/sbin:/sbin
export PATH

case $1 in
[0-9]*) maxmounts=$1;;
"") maxmounts=99999;;
*) echo "usage: $0 [WARN maxmounts]"; exit 3;;
esac

# CC version:
ver=`
{ cleartool -version; } 2>/dev/null |
awk '$2=="MVFS" {mvfs=$4} $1=="cleartool" {ver=$2} END {if (ver!="") if (ver==mvfs) print ver; else print mvfs " is not " ver}'
`
case $ver in
"")
  echo "(OK) cleartool not found"
  exit 0
;;
" is not "*)
  echo "CRITICAL: MVFS is not loaded"
  exit 2
;;
*" is not "*)
  echo "WARNING: MVFS $ver"
  exit 1
;;
esac

# Check if albd_server is running
if pgrep -xu 0 albd_server >/dev/null
then
  :
else
  echo "CRITICAL: albd_server not running"
  exit 2
fi

# CC mounts:
mounts=`mount -v | awk '($3~/^\/vobs\// && $5~/[Mm][Vv][Ff][Ss]/) {++cnt} END {print cnt}'`

if [ -z "$mounts" ]
then
  echo "WARNING: no VOBs are mounted"
  exit 1
elif [ "$mounts" -gt "$maxmounts" ]
then
  echo "WARNING: $mounts mounted VOBs exceed $maxmounts"
  exit 1
fi

echo "OK: ClearCase $ver, $mounts VOBs mounted"
